@@ -389,8 +389,7 @@ class BigQueryClient(BigBluePickAPI):
         # Run header statements if there are any
         if sql_script.header_statements:
             code = "".join(f"{hs};\n" for hs in sql_script.header_statements)
-            header_job_config = bigquery.QueryJobConfig()
-            header_job_config.create_session = True
+            header_job_config = bigquery.QueryJobConfig(create_session=True)
             job = client.query(code, job_config=header_job_config)
             job.result()
             session_id = job.session_info.session_id  # type: ignore
@@ -446,15 +445,30 @@ class BigQueryClient(BigBluePickAPI):
         source = BigQueryDialect.convert_table_ref_to_bigquery_table_reference(
             table_ref=from_table_ref, project=self.write_project_id
         )
+
+        # First, delete the destination table if it exists. We need to do this because the existing
+        # table potentially has a different clustering configuration, which cannot be changed with
+        # a CLONE.
+        delete_code = f"""
+        DROP TABLE IF EXISTS {destination};
+        """
+        header_job_config = bigquery.QueryJobConfig(create_session=True)
+        job = self.client.query(delete_code, job_config=header_job_config)
+        job.result()
+        session_id = job.session_info.session_id
+
+        # Now, clone the source table to the destination.
         clone_code = f"""
-        CREATE OR REPLACE TABLE {destination}
+        CREATE TABLE {destination}
         CLONE {source}
         """
         job_config = self.make_job_config(
             script=scripts.SQLScript(
                 table_ref=to_table_ref, code=clone_code, sql_dialect=BigQueryDialect, fields=[]
-            )
+            ),
+            connection_properties=[bigquery.ConnectionProperty(key="session_id", value=session_id)],
         )
+
         return BigQueryJob(
             client=self,
             query_job=self.client.query(clone_code, job_config=job_config, location=self.location),
